==> nextcloud-15.0.14.tar.bz2: nextcloud/apps/workflowengine/l10n/sv.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Den valda operatören är felaktig",
    "The given regular expression is invalid" : "Det valda vanliga uttrycket är felaktigt",
    "The given file size is invalid" : "Den valda filstorleken är felaktig",
    "The given tag id is invalid" : "Den valda taggen är felaktig",
    "The given IP range is invalid" : "Det valda IP-spannet är felaktigt",
    "The given IP range is not valid for IPv4" : "Det valda IP-spannet är felaktigt för IPv4",
    "The given IP range is not valid for IPv6" : "Det valda IP-spannet är felaktigt för IPv6",
    "The given time span is invalid" : "Det valda tidsspannet är felaktigt",
    "The given start time is invalid" : "Den valda starttiden är felaktig",
    "The given end time is invalid" : "Den valda sluttiden är felaktig",
    "The given group does not exist" : "Den valda gruppen finns inte",
    "File" : "Fil",
    "File created" : "Fil skapad",
    "File updated" : "Fil uppdaterad",
    "File renamed" : "Fil omdöpt",
    "File deleted" : "Fil raderad",
    "File accessed" : "Fil öppnad",
    "File copied" : "Fil kopierad",
    "Tag assigned" : "Tagg tilldelad",
    "Someone" : "Någon",
    "%s created %s" : "%s skapad %s",
    "%s modified %s" : "%s ändrad %s",
    "%s deleted %s" : "%s raderad %s",
    "%s renamed %s" : "%s omdöpt %s",
    "%s copied %s" : "%s kopierad %s",
    "%s assigned %s to %s" : "%s tilldelad %s till %s",
    "Operation #%s does not exist" : "Operationen #%s existerar inte",
    "Entity %s does not exist" : "Objekt 1%s finns inte",
    "Entity %s is invalid" : "Entitet %s är ogiltig",
    "No events are chosen." : "Inga händelser valda",
    "Entity %s has no event %s" : "Objekt 1%s har ingen händelse 1%s",
    "Operation %s does not exist" : "Operationen %s existerar inte",
    "Operation %s is invalid" : "Operationen %s är ogiltig",
    "Check %s does not exist" : "Kontroll av %s existerar inte",
    "Check %s is invalid" : "Kontroll av %s är ogiltig",
    "Check %s is not allowed with this entity" : "Kontroll 1%s tillåts ej för det här objektet",
    "Check #%s does not exist" : "Kontroll av #%s existerar inte",
    "Check %s is invalid or does not exist" : "Kontroll av %s är ogiltig eller existerar inte",
    "Flow" : "Flöde",
    "Nextcloud workflow engine" : "Nextcloud arbetsflödesmotor",
    "Select a filter" : "Välj ett filter",
    "Select a comparator" : "Välj en jämförelse",
    "Select a file type" : "Välj en filtyp",
    "e.g. httpd/unix-directory" : "t.ex. httpd/unix-directory",
    "Images" : "Bilder",
    "Office documents" : "Officedokument",
    "PDF documents" : "PDF-dokument",
    "Custom mimetype" : "Anpassad mimetyp",
    "Select a tag" : "Välj en tagg",
    "No results" : "Inga resultat",
    "%s (invisible)" : "%s (osynlig)",
    "%s (restricted)" : "%s (begränsad)",
    "Please enter a valid time span" : "Ange ett giltigt tidsintervall",
    "Select a request URL" : "Välj en webbadress för begäran",
    "Predefined URLs" : "Förinställda webbadresser",
    "Files WebDAV" : "Filer WebDAV",
    "Others" : "Övriga",
    "Custom URL" : "Anpassad webbadress",
    "Select a user agent" : "Välj en användaragent",
    "Android client" : "Android-klient",
    "iOS client" : "iOS-klient",
    "Desktop client" : "Skrivbordsklient",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook - tillägg",
    "Custom user agent" : "Anpassad användaragent",
    "Add new flow" : "Lägg till nytt flöde",
    "When" : "När",
    "and" : "och",
    "Cancel" : "Avbryt",
    "Delete" : "Radera",
    "The configuration is invalid" : "Konfigurationen är felaktig",
    "Active" : "Aktiv",
    "Save" : "Spara",
    "Available flows" : "Tillgängliga flöden",
    "For details on how to write your own flow, check out the development documentation." : "För information om hur du skriver ditt eget flöde, se utvecklingsdokumentationen.",
    "More flows" : "Fler flöden",
    "Browse the app store" : "Bläddra i appbutiken",
    "Show less" : "Visa mindre",
    "Show more" : "Visa mer",
    "Configured flows" : "Konfigurerade flöden",
    "Your flows" : "Dina flöden",
    "File name" : "Filnamn",
    "is" : "är",
    "is not" : "är inte",
    "matches" : "träffar",
    "does not match" : "matchar inte",
    "File MIME type" : "Filens MIME-typ",
    "File size (upload)" : "Filstorlek (uppladdning)",
    "less" : "mindre",
    "less or equals" : "mindre eller motsvarar",
    "greater or equals" : "större eller motsvarar",
    "greater" : "större",
    "Request remote address" : "Begär extern adress",
    "matches IPv4" : "matchar IPv4",
    "does not match IPv4" : "matchar inte IPv4",
    "matches IPv6" : "matchar IPv6",
    "does not match IPv6" : "matchar inte IPv6",
    "File system tag" : "Filens systemtagg",
    "is tagged with" : "är taggad med",
    "is not tagged with" : "är inte taggad med",
    "Request URL" : "Begär webbadress",
    "Request time" : "Begärningstid",
    "between" : "mellan",
    "not between" : "inte mellan",
    "Request user agent" : "Begär användaragent",
    "User group membership" : "Användargruppsmedlemskap",
    "is member of" : "är medlem i",
    "is not member of" : "är inte medlem i",
    "Short rule description" : "Kort regelbeskrivning",
    "Add rule" : "Lägg till regel",
    "Reset" : "Återställ",
    "Saving…" : "Sparar...",
    "Group list is empty" : "Grupplistan är tom",
    "Unable to retrieve the group list" : "Kan inte hämta grupplistan",
    "Saved" : "Sparad",
    "Saving failed:" : "Gick ej att spara: ",
    "Add rule group" : "Lägg till regelgrupp",
    "Example: {placeholder}" : "Exempel: {placeholder}",
    "Select tag…" : "Välj tagg...",
    "Start" : "Början",
    "End" : "Slutet",
    "Select timezone…" : "Välj tidszon...",
    "Sync clients" : "Synkroniseringsklienter",
    "Workflow" : "Arbetsflöde",
    "Files workflow engine" : "Arbetsflödesmotor för Filer",
    "Open documentation" : "Öppna dokumentation",
    "Loading…" : "Laddar...",
    "Tag management" : "Tagghantering"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.0.tar.bz2: nextcloud/apps/workflowengine/l10n/sv.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Den valda operatören är felaktig",
    "The given regular expression is invalid" : "Det valda vanliga uttrycket är felaktigt",
    "The given file size is invalid" : "Den valda filstorleken är felaktig",
    "The given tag id is invalid" : "Den valda taggen är felaktig",
    "The given IP range is invalid" : "Det valda IP-spannet är felaktigt",
    "The given IP range is not valid for IPv4" : "Det valda IP-spannet är felaktigt för IPv4",
    "The given IP range is not valid for IPv6" : "Det valda IP-spannet är felaktigt för IPv6",
    "The given time span is invalid" : "Det valda tidsspannet är felaktigt",
    "The given start time is invalid" : "Den valda starttiden är felaktig",
    "The given end time is invalid" : "Den valda sluttiden är felaktig",
    "The given group does not exist" : "Den valda gruppen finns inte",
    "File" : "Fil",
    "File created" : "Fil skapad",
    "File updated" : "Fil uppdaterad",
    "File renamed" : "Fil omdöpt",
    "File deleted" : "Fil raderad",
    "File accessed" : "Fil öppnad",
    "File copied" : "Fil kopierad",
    "Tag assigned" : "Tagg tilldelad",
    "Someone" : "Någon",
    "%s created %s" : "%s skapad %s",
    "%s modified %s" : "%s ändrad %s",
    "%s deleted %s" : "%s raderad %s",
    "%s accessed %s" : "%s öppnade %s",
    "%s renamed %s" : "%s omdöpt %s",
    "%s copied %s" : "%s kopierad %s",
    "%s assigned %s to %s" : "%s tilldelad %s till %s",
    "Operation #%s does not exist" : "Operationen #%s existerar inte",
    "Entity %s does not exist" : "Objekt 1%s finns inte",
    "Entity %s is invalid" : "Entitet %s är ogiltig",
    "No events are chosen." : "Inga händelser valda",
    "Entity %s has no event %s" : "Objekt 1%s har ingen händelse 1%s",
    "Operation %s does not exist" : "Operationen %s existerar inte",
    "Operation %s is invalid" : "Operationen %s är ogiltig",
    "At least one check needs to be provided" : "Minst en kontroll måste tillhandahållas",
    "The provided operation data is too long" : "Den angivna operationsdatan är för lång",
    "Invalid check provided" : "Ogiltig kontroll angavs",
    "Check %s does not exist" : "Kontroll av %s existerar inte",
    "Check %s is invalid" : "Kontroll av %s är ogiltig",
    "Check %s is not allowed with this entity" : "Kontroll %s tillåts inte med denna enhet",
    "The provided check value is too long" : "Det angivna kontrollvärdet är för långt",
    "Check #%s does not exist" : "Kontroll av #%s existerar inte",
    "Check %s is invalid or does not exist" : "Kontroll av %s är ogiltig eller existerar inte",
    "Flow" : "Flöde",
    "Nextcloud workflow engine" : "Nextcloud arbetsflödesmotor",
    "Select a filter" : "Välj ett filter",
    "Select a comparator" : "Välj en jämförelse",
    "Remove filter" : "Ta bort filter",
    "Audio" : "Ljud",
    "Folder" : "Mapp",
    "Images" : "Bilder",
    "Office documents" : "Office-dokument",
    "PDF documents" : "PDF-dokument",
    "Video" : "Film",
    "Custom MIME type" : "Anpassad MIME-typ",
    "Custom mimetype" : "Anpassad mimetyp",
    "Select a file type" : "Välj en filtyp",
    "e.g. httpd/unix-directory" : "t.ex. httpd/unix-directory",
    "Please enter a valid time span" : "Ange ett giltigt tidsintervall",
    "Files WebDAV" : "Filer WebDAV",
    "Custom URL" : "Anpassad webbadress",
    "Select a request URL" : "Välj en webbadress för begäran",
    "Android client" : "Android-klient",
    "iOS client" : "iOS-klient",
    "Desktop client" : "Skrivbordsklient",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook - tillägg",
    "Custom user agent" : "Anpassad användaragent",
    "Select a user agent" : "Välj en användaragent",
    "Select groups" : "Välj grupper",
    "Groups" : "Grupper",
    "Type to search for group …" : "Skriv för att söka efter grupp ...",
    "Select a trigger" : "Välj en utlösare",
    "At least one event must be selected" : "Minst en händelse måste väljas",
    "Add new flow" : "Lägg till nytt flöde",
    "The configuration is invalid" : "Konfigurationen är felaktig",
    "Active" : "Aktiv",
    "Save" : "Spara",
    "When" : "När",
    "and" : "och",
    "Add a new filter" : "Lägg till nytt filter",
    "Cancel" : "Avbryt",
    "Delete" : "Radera",
    "Available flows" : "Tillgängliga flöden",
    "For details on how to write your own flow, check out the development documentation." : "För information om hur du skriver ditt eget flöde, se utvecklingsdokumentationen.",
    "No flows installed" : "Inga flöden installerade",
    "Ask your administrator to install new flows." : "Be din administratör att installera nya flöden.",
    "More flows" : "Fler flöden",
    "Browse the App Store" : "Bläddra i appbutiken",
    "Show less" : "Visa mindre",
    "Show more" : "Visa mer",
    "Configured flows" : "Konfigurerade flöden",
    "Your flows" : "Dina flöden",
    "No flows configured" : "Inga flöden har konfigurerats",
    "matches" : "träffar",
    "does not match" : "matchar inte",
    "is" : "är",
    "is not" : "är inte",
    "File name" : "Filnamn",
    "File MIME type" : "Filens MIME-typ",
    "File size (upload)" : "Filstorlek (uppladdning)",
    "less" : "mindre",
    "less or equals" : "mindre eller motsvarar",
    "greater or equals" : "större eller motsvarar",
    "greater" : "större",
    "Request remote address" : "Begär extern adress",
    "matches IPv4" : "matchar IPv4",
    "does not match IPv4" : "matchar inte IPv4",
    "matches IPv6" : "matchar IPv6",
    "does not match IPv6" : "matchar inte IPv6",
    "File system tag" : "Filens systemtagg",
    "is tagged with" : "är taggad med",
    "is not tagged with" : "är inte taggad med",
    "Request URL" : "Begär webbadress",
    "Request time" : "Begärningstid",
    "between" : "mellan",
    "not between" : "inte mellan",
    "Request user agent" : "Begär användaragent",
    "Group membership" : "Gruppmedlemskap",
    "is member of" : "är medlem i",
    "is not member of" : "är inte medlem i"
},
"nplurals=2; plural=(n != 1);");
